#-------------------------------------------------------------------------------
#
# Thomas Thomassen
# thomas[at]thomthom[dot]net
#
#-------------------------------------------------------------------------------


module TT::Plugins::BezierSurfaceTools

  # @since 1.0.0
  module Commands

    # @return [UI::Command]
    # @since 1.0.0
    def self.create_quad_patch
      unless @create_quad_patch
        cmd = UI::Command.new( '创建四边形面片' ) {
          Operations.draw_quadpatch
        }
        cmd.small_icon = File.join( PATH_ICONS, 'QuadPatch_16.png' )
        cmd.large_icon = File.join( PATH_ICONS, 'QuadPatch_24.png' )
        cmd.status_bar_text = '创建四边形贝兹曲面，双击贝兹曲面可进入编辑状态。'
        cmd.tooltip = '创建四边形贝兹曲面'
        @create_quad_patch = cmd
      end
      @create_quad_patch
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.create_tri_patch
      unless @create_tri_patch
        cmd = UI::Command.new( '创建三角形面片' ) {
          UI.messagebox( '不可执行' )
        }
        cmd.small_icon = File.join( PATH_ICONS, 'TriPatch_16.png' )
        cmd.large_icon = File.join( PATH_ICONS, 'TriPatch_24.png' )
        cmd.status_bar_text = '创建三角形贝兹曲面。'
        cmd.tooltip = '创建三角形贝兹曲面，双击贝兹曲面可进入编辑状态。'
        cmd.set_validation_proc { MF_GRAYED }
        @create_tri_patch = cmd
      end
      @create_tri_patch
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.convert_to_mesh
      unless @convert_to_mesh
        cmd = UI::Command.new( '转换为可编辑网格' ) {
          Operations.convert_selected_to_mesh
        }
        cmd.status_bar_text = '将选定的表面转换为可编辑网格。'
        cmd.tooltip = '将选定的表面转换为可编辑网格'
        @convert_to_mesh = cmd
      end
      @convert_to_mesh
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.convert_to_quadmesh
      unless @convert_to_quadmesh
        cmd = UI::Command.new( '转换为可编辑的四边形' ) {
          Operations.convert_selected_to_quadmesh
        }
        cmd.status_bar_text = '将选定的曲面转换为可编辑的四边形。'
        cmd.tooltip = '将选定的曲面转换为可编辑的四边形'
        @convert_to_quadmesh = cmd
      end
      @convert_to_quadmesh
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.clone
      unless @clone
        cmd = UI::Command.new( '复制曲面' ) {
          UI.messagebox( '不可执行' )
        }
        cmd.status_bar_text = '复制选定的曲面。'
        cmd.tooltip = '复制选定的曲面'
        cmd.set_validation_proc { MF_GRAYED }
        @clone = cmd
      end
      @clone
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.replace_clone
      unless @replace_clone
        cmd = UI::Command.new( '替换复制曲面' ) {
          UI.messagebox( '不可执行' )
        }
        cmd.status_bar_text = '替换所有复制曲面。'
        cmd.tooltip = '替换所有复制曲面'
        cmd.set_validation_proc { MF_GRAYED }
        @replace_clone = cmd
      end
      @replace_clone
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.select_clone
      unless @select_clone
        cmd = UI::Command.new( '选择复制曲面' ) {
          UI.messagebox( '不可执行' )
        }
        cmd.status_bar_text = '选择所有复制曲面。'
        cmd.tooltip = '选择所有复制曲面'
        cmd.set_validation_proc { MF_GRAYED }
        @select_clone = cmd
      end
      @select_clone
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.toggle_properties
      unless @toggle_properties
        cmd = UI::Command.new( '实体属性' ) {
          PLUGIN::PropertiesWindow.toggle
        }
        cmd.status_bar_text = '显示或隐藏属性窗口。'
        cmd.tooltip = '显示或隐藏属性窗口'
        @toggle_properties = cmd
      end
      @toggle_properties
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.update_selected
      unless @update_selected
        cmd = UI::Command.new( '更新曲面' ) {
          Operations.update_selected_surface
        }
        cmd.status_bar_text = '更新选中的曲面。'
        cmd.tooltip = '更新选中的曲面'
        @update_selected = cmd
      end
      @update_selected
    end

    # @return [UI::Command]
    # @since 1.0.0
    def self.extract_edges
      unless @extract_edges
        cmd = UI::Command.new( '提取边线' ) {
          UI.messagebox( '不可执行' )
        }
        cmd.status_bar_text = '将贝兹边线提取到一组贝兹曲线中。'
        cmd.tooltip = '提取贝兹边线'
        cmd.set_validation_proc { MF_GRAYED }
        @extract_edges = cmd
      end
      @extract_edges
    end

     # @return [UI::Command]
    # @since 1.0.0
    def self.extract_control_grid
      unless @extract_control_grid
        cmd = UI::Command.new( '提取控制网格' ) {
          UI.messagebox( '不可执行' )
        }
        cmd.status_bar_text = '将控制网格提取到一个组中。'
        cmd.tooltip = '提取控制网格'
        cmd.set_validation_proc { MF_GRAYED }
        @extract_control_grid = cmd
      end
      @extract_control_grid
    end

  end # module Commands

end # module
